# Romance.rb

[![Version](https://img.shields.io/github/v/tag/sashite/romance.rb?label=Version&logo=github)](https://github.com/sashite/romance.rb/releases)
[![Yard documentation](https://img.shields.io/badge/Yard-documentation-blue.svg?logo=github)](https://rubydoc.info/github/sashite/romance.rb/main)
[![CI](https://github.com/sashite/romance.rb/workflows/CI/badge.svg?branch=main)](https://github.com/sashite/romance.rb/actions?query=workflow%3Aci+branch%3Amain)
[![RuboCop](https://github.com/sashite/romance.rb/workflows/RuboCop/badge.svg?branch=main)](https://github.com/sashite/romance.rb/actions?query=workflow%3Arubocop+branch%3Amain)
[![License](https://img.shields.io/github/license/sashite/romance.rb?label=License&logo=github)](https://github.com/sashite/romance.rb/raw/main/LICENSE.md)

> Generic chess moves legalizer.

## Installation

Add this line to your application's Gemfile:

```ruby
gem "romance"
```

And then execute:

```sh
bundle install
```

Or install it yourself as:

```sh
gem install romance
```

## Usage

To be legal, a move must

* be included in the pseudo-legal moves listing;
* not repeat the position more than once.

The first player whose king is captured loses the game.

## Example

Let's replay [The Shortest Possible Game of Shogi](https://userpages.monmouth.com/~colonel/shortshogi.html).

First of all, we can install the [Shogi tablebase](https://github.com/sashite/pseudo_legal_move_tablebase-shogi.rb):

```sh
gem install pseudo_legal_move_tablebase-shogi
```

And then, we can apply each move, one by one:

```ruby
require "pseudo_legal_move_tablebase/shogi"
require "romance"

feen = "s:l,s:n,s:s,s:g,s:-k,s:g,s:s,s:n,s:l/1,s:r,5,s:b,1/s:p,s:p,s:p,s:p,s:p,s:p,s:p,s:p,s:p/9/9/9/S:P,S:P,S:P,S:P,S:P,S:P,S:P,S:P,S:P/1,S:B,5,S:R,1/S:L,S:N,S:S,S:G,S:-K,S:G,S:S,S:N,S:L 0 -"

game = Romance::Game.load(PseudoLegalMoveTablebase::Shogi::DB, feen)

moves = [
  [56, 47, "S:P",  nil],   [3, 11, "s:g", nil],
  [64, 24, "S:+B", "S:P"], [5, 14, "s:g", nil],
  [24, 14, "S:+B", "S:G"], [4, 3, "s:-k", nil],
  [nil, 13, "S:G", nil]
]

moves.each do |move|
  game.play!(move)
end
```

When an illegal move is submitted, an error is raised:

```ruby
game.play!([3, 4, "s:-k", nil]) # => raise Romance::Error::KingInCheck
```

## License

The code is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## About Sashite

This [gem](https://rubygems.org/gems/romance) is maintained by [Sashite](https://sashite.com/).

With some [lines of code](https://github.com/sashite/), let's share the beauty of Chinese, Japanese and Western cultures through the game of chess!
